import{g as P}from"../index-XTT3-3H0.js";var g={exports:{}},b=g.exports,y;function E(){return y||(y=1,(function(w,D){(function(p,l){w.exports=l()})(b,function(){var p=function(){function l(n){return i.appendChild(n.dom),n}function f(n){for(var a=0;a<i.children.length;a++)i.children[a].style.display=a===n?"block":"none";c=n}var c=0,i=document.createElement("div");i.style.cssText="position:fixed;top:0;left:0;cursor:pointer;opacity:0.9;z-index:10000",i.addEventListener("click",function(n){n.preventDefault(),f(++c%i.children.length)},!1);var o=(performance||Date).now(),r=o,e=0,x=l(new p.Panel("FPS","#0ff","#002")),v=l(new p.Panel("MS","#0f0","#020"));if(self.performance&&self.performance.memory)var h=l(new p.Panel("MB","#f08","#201"));return f(0),{REVISION:16,dom:i,addPanel:l,showPanel:f,begin:function(){o=(performance||Date).now()},end:function(){e++;var n=(performance||Date).now();if(v.update(n-o,200),n>r+1e3&&(x.update(1e3*e/(n-r),100),r=n,e=0,h)){var a=performance.memory;h.update(a.usedJSHeapSize/1048576,a.jsHeapSizeLimit/1048576)}return n},update:function(){o=this.end()},domElement:i,setMode:f}};return p.Panel=function(l,f,c){var i=1/0,o=0,r=Math.round,e=r(window.devicePixelRatio||1),x=80*e,v=48*e,h=3*e,n=2*e,a=3*e,s=15*e,u=74*e,d=30*e,m=document.createElement("canvas");m.width=x,m.height=v,m.style.cssText="width:80px;height:48px";var t=m.getContext("2d");return t.font="bold "+9*e+"px Helvetica,Arial,sans-serif",t.textBaseline="top",t.fillStyle=c,t.fillRect(0,0,x,v),t.fillStyle=f,t.fillText(l,h,n),t.fillRect(a,s,u,d),t.fillStyle=c,t.globalAlpha=.9,t.fillRect(a,s,u,d),{dom:m,update:function(S,R){i=Math.min(i,S),o=Math.max(o,S),t.fillStyle=c,t.globalAlpha=1,t.fillRect(0,0,x,s),t.fillStyle=f,t.fillText(r(S)+" "+l+" ("+r(i)+"-"+r(o)+")",h,n),t.drawImage(m,a+e,s,u-e,d,a,s,u-e,d),t.fillRect(a+u-e,s,e,d),t.fillStyle=c,t.globalAlpha=.9,t.fillRect(a+u-e,s,e,r((1-S/R)*d))}}},p})})(g)),g.exports}var M=E();const k=P(M);export{k as S};
